\name{HyperbolicDistribution}
\alias{hyperb}

\title{
  The Library `HyperbolicDist': Summary Information
}

\description{
This library provides a collection of functions for working with
the hyperbolic distribution. Included are the 
density function, distribution function, quantiles, 
random number generation and fitting the hyperbolic distribution
to data (\code{fit.hyperb}). The function \code{hyperb.change.pars}
will interchange parameter values between different parameterisations.
The mean, variance and mode of a given hyperbolic distribution are
given by \code{hyperb.mean}, \code{hyperb.var}, and \code{hyperb.mode}
respectively. For assessing the fit of the hyperbolic distribution to
a set of data, the log-histogram is useful. See \code{\link{log.hist}}.
}

\seealso{
\code{\link{dhyperb}}, \code{\link{fit.hyperb}}, 
\code{\link{log.hist}}, \code{\link{hyperb.change.pars}}, and
\code{\link{hyperb.mean}}.
}

\author{David Scott \email{d.scott@auckland.ac.nz}}

\section{Acknowledgements}{
  A number of students have worked on the package: Ai-Wei Lee, Jennifer Tso,
  and Richard Trendall.
  
  Thanks to Ross Ihaka and Paul Murrell for their willingness to answer
  my questions, and to all the core group for the development of R.
}
\references{
  Barndorff-Nielsen, O. (1977)
  Exponentially decreasing distributions for the logarithm of particle size,
  \emph{Proc. Roy. Soc. Lond.},
  A\bold{353}, 401--419.
  
  Barndorff-Nielsen, O. and Blaesild, P (1983).
  Hyperbolic distributions. 
  In \emph{Encyclopedia of Statistical Sciences}, 
  eds., Johnson, N. L., Kotz, S. and Read, C. B., Vol. 3,
  pp. 700--707. New York: Wiley.
  
  Fieller, N. J., Flenley, E. C. and Olbricht, W. (1992)
  Statistics of particle size data.
  \emph{Appl. Statist.},
  \bold{41}, 127--146.
}


\section{LICENCE}{
This library and its documentation are usable under the terms of the 
"GNU General Public License", a copy of which is distributed with the 
package.
}


\keyword{distribution}

\eof
\name{SandP500}
\alias{SandP500}
\title{Standard and Poor New York Stock Exchange market price index }
\description{
  This data set gives the value of the Standard and Poor New York
  Stock Exchange market price index at year end, from 1800 to 2001.
}
\usage{data(SandP500)}
\format{
  A vector of 202 observations.
}
\source{
  \url{http://www.globalfindata.com}
}
\references{
  Brown, Barry W., Spears, Floyd M. and Levy, Lawrence B. (2002)
  The log \emph{F}: a distribution for all seasons.
  \emph{Computational Statistics},
  \bold{17}, 47--58.
}
\examples{
data(SandP500)
## Consider proportional changes in the index
change<-SandP500[-length(SandP500)]/SandP500[-1]
hist(change)
## Fit hyperbolic distribution to changes
fit.hyperb(change)

}
\keyword{datasets}

\eof
\name{calculate.range}
\alias{calculate.range}
\title{Range of a Hyperbolic Distribution}
\description{
  Given the parameter vector theta of a hyperbolic distribution,
  this function calculates the range over which the distribution
  is non-zero, to a specified tolerance. The parameterisation used
  is the pi/zeta one (see \code{\link{dhyperb}}). To use another
  parameterisation, use \code{\link{hyperb.change.pars}}. 
}
\usage{
calculate.range(theta, tol = 10^(-5))
}
\arguments{
  \item{theta}{Value of parameter vector specifying the hyperbolic
    distribution.}
  \item{tol}{Tolerance}
}
\details{
  The particular hyperbolic distribution being considered is specified
  by the value of the parameter value \code{theta}. The function calculates
  the effective range of the distribution, which is useful in calculating
  the distribution function and quantiles, but also in determining
  the range when plotting the density. By effective range is meant that
  the probability of an observation being greater than the upper end is
  less than the specified tolerance \code{tol}. Likewise for being smaller
  than the lower end of the range.
}
\value{
  A two-component vector giving the lower and upper ends of the range.
}
\references{ 
  Barndorff-Nielsen, O. and Blaesild, P (1983).
  Hyperbolic distributions. 
  In \emph{Encyclopedia of Statistical Sciences}, 
  eds., Johnson, N. L., Kotz, S. and Read, C. B., Vol. 3,
  pp. 700--707. New York: Wiley. 
}
\author{David Scott \email{d.scott@auckland.ac.nz},
  Jennifer Tso, Richard Trendall}

\seealso{
  \code{\link{dhyperb}}, \code{\link{hyperb.change.pars}}
}

\examples{
hyperb.range <- calculate.range(c(3,5,1,0),tol=10^(-2))
curve(dhyperb(x,c(3,5,1,0)),hyperb.range[1],hyperb.range[2])
}
\keyword{distribution}

\eof
\name{dhyperb}
\alias{dhyperb}
\alias{phyperb}
\alias{qhyperb}
\alias{rhyperb}

\title{Hyperbolic Distribution}

\description{
  Density function, distribution function, quantiles and 
  random number generation for the hyperbolic distribution 
  with parameter vector \code{theta}.
}

\usage{
dhyperb(x, theta, K.nu=NULL, log.pars=FALSE)
phyperb(q, theta, tol=10^(-5), subdivisions=100)
qhyperb(p, theta, tol=10^(-5), n.interpol=100, subdivisions=100, ...)
rhyperb(n, theta)
}

\arguments{
  \item{x,q}{vector of quantiles}
  \item{p}{vector of probabilities}
  \item{n}{number of observations to be generated}
  \item{theta}{parameter vector taking the form \code{c(pi,zeta,delta,mu)}}
  \item{K.nu}{sets the value of the Bessel function in the density. 
    See \bold{Details}}
  \item{log.pars}{logical; if \code{TRUE} the second and third components 
    of theta are taken to be log(zeta) and log(delta) respectively}
  \item{tol}{an upper bound on the error in the distribution function. 
    See \bold{Details}}
  \item{subdivisions}{the maximum number of subdivisions used to integrate 
    the density returning the distribution function}
  \item{n.interpol}{the number of points used in qhyperb for cubic spline 
    interpolation (see \code{splinefun}) of the distribution function}
  \item{\dots}{passes arguments to \code{uniroot}.  See \bold{Details}}
}

\details{
  The hyperbolic distribution has density

  \deqn{f(x)=\frac{1}{2\sqrt{1+\pi^2}K_1(\zeta)} %
    e^{-\zeta[\sqrt{1+\pi^2}\sqrt{1+(\frac{x-\mu}{\delta})^2}-%
    \pi\frac{x-\mu}{\delta}]}}{ %
  f(x)=1/(2 sqrt(1+pi^2) K_1(zeta)) %
  exp(-zeta(sqrt(1+pi^2) sqrt(1+((x-mu)/delta)^2)-pi (x-mu)/delta))}

  where \deqn{K_1()}{K_1()} is the modified Bessel function of the 
  third kind with order 1.

  A succinct description of the hyperbolic distribution is given in
  Barndorff-Nielsen and Blaesild (1983). Three different possible
  parameterisations are described in that paper. All use location and
  scale parameters \eqn{\mu}{mu} and \eqn{\delta}{delta}. There are two
  other parameters in each case.

  Use \code{hyperb.change.pars} to convert from the alpha/beta or phi/gamma 
  parameterisations to the parameterisation (pi/zeta) used above.

  \code{phyperb} uses a numerical integration routine (\code{integrate()}) 
  to integrate the density \code{dhyperb}.  See the notes on \code{integrate} 
  for the shortfalls of this procedure.  In particular note the weakness of 
  this function when integrating over a region that is approximately zero.

  \code{qhyperb} uses \code{splinefun} on values generated by \code{pyhyperb} 
  to approximate the distribution function.  The quantiles are then found 
  using the \code{uniroot} function.

  \code{rhyperb} is based on the HYP algorithm given by Atkinson (1982).
}

\value{
  \code{dhyperb} gives the density, \code{phyperb} gives the distribution 
  function, \code{qhyperb} gives the quantile function and \code{rhyperb} 
  generates random variates.
}

\references{
  Atkinson, A.C. (1982). 
  The simulation of generalized inverse Gaussian and hyperbolic random
  variables. 
  \emph{SIAM J. Sci. Stat. Comput.}, 
  \bold{3}, 502--515.

  Barndorff-Nielsen, O. and Blaesild, P (1983).
  Hyperbolic distributions. 
  In \emph{Encyclopedia of Statistical Sciences}, 
  eds., Johnson, N. L., Kotz, S. and Read, C. B., Vol. 3,
  pp. 700--707. New York: Wiley.
}

\author{David Scott \email{d.scott@auckland.ac.nz}, 
Ai-Wei Lee, Jennifer Tso, Richard Trendall}

\seealso{
  \code{\link{integrate}} for its shortfalls, \code{\link{splinefun}}, 
  \code{\link{uniroot}} and \code{\link{hyperb.change.pars}} for 
  changing parameters to the pi/zeta parameterisation
}

\examples{
theta <- c(0,1,1,0)
data.vector <- rhyperb(500,theta)
par(mfrow=c(1,2))
hist(data.vector,freq=FALSE)
curve(dhyperb(x,theta),add=TRUE,
      range(data.vector)[1],range(data.vector)[2])
log.hist(data.vector)
curve(log(dhyperb(x,theta)),add=TRUE,
      range(data.vector)[1],range(data.vector)[2])
hyperb.range <- calculate.range(c(0,1,1,0),tol=10^(-2))
curve(dhyperb(x,theta),
      hyperb.range[1],hyperb.range[2],log="")
title("Density of the\n Hyperbolic Distribution")
curve(phyperb(x,theta),
      hyperb.range[1],hyperb.range[2],log="")
title("Distribution Function of the\n Hyperbolic Distribution")
}

\keyword{distribution} 
\eof
\name{dskewlap}
\alias{dskewlap}
\title{Skew-Laplace Density}
\description{
  Calculates the density of the skew-Laplace distribution.
}
\usage{
dskewlap(x, theta)
}
\arguments{
  \item{x}{Vector of quantiles}
  \item{theta}{Vector of parameters of the skew-Laplace distribution:
    alpha, beta and mu}
}
\details{
  The central skew-Laplace has mode zero, and is a mixture of a (negative)
  exponential distribution with mean beta, and the negative of an 
  exponential distribution with mean alpha. The weights of the positive
  and negative components are proportional to their means.
  
  The general skew-Laplace distribution is a shifted central skew-Laplace
  distribution, where the mode is given by mu.
  
  The density is given by:
  \deqn{f(x)=\frac{1}{\alpha+\beta} e^{(x - \mu)/\alpha}}{ %
  f(x)=(1/(alpha+beta)) e^((x - mu)/alpha)}
  for \eqn{x\leq\mu}{x <= mu}, and
  \deqn{f(x)=\frac{1}{\alpha+\beta} e^{-(x - \mu)/\beta}}{ %
  f(x)=(1/(alpha+beta)) e^(-(x - mu)/beta)}
  for \eqn{x\geq\mu}{x >= mu}
}
\value{
  \code{dskewlap} gives the density of the skew-Laplace distribution.
}
\references{
  Fieller, N. J., Flenley, E. C. and Olbricht, W. (1992)
  Statistics of particle size data.
  \emph{Appl. Statist.},
  \bold{41}, 127--146.
}
\author{David Scott \email{d.scott@auckland.ac.nz}, 
Ai-Wei Lee, Richard Trendall}

\seealso{\code{\link{fit.hyperb}}}

\examples{
theta <- c(1,2,1)
curve(dskewlap(x,theta),from=-3,to=6,n=1000)
}
\keyword{distribution} 

\eof
\name{fit.hyperb}

\alias{fit.hyperb}

\title{Fit the Hyperbolic Distribution to Data}
\description{
    Fits a hyperbolic distribution to data.  
    Displays the histogram, log-histogram (both with fitted densities)
    and qqplot for the fit which has the maximum likelihood.
}

\usage{
    fit.hyperb(x, freq = NULL, breaks = NULL, theta.start = NULL, 
      start.values = c("all"), method = c("BFGS"), max.lh = FALSE, 
      plots = TRUE, leave.on = FALSE, controlbfgs = list(maxit = 100), 
      controlnm = list(maxit = 1000), maxitnlm = 1500, ...)
}

\arguments{
  \item{x}{data vector}
  \item{freq}{a vector of weights with length equal to \code{length(x)}}
  \item{breaks}{breaks for histogram, defaults to those generated by 
    \code{hist(x,right=F,plot=F)}}
  \item{theta.start}{a user specified starting parameter vector taking 
    the form \code{c(pi,zeta,delta,mu)}}
  \item{start.values}{vector of the different starting values to consider.  
    See \bold{Details}}
  \item{method}{vector of the different optimisation methods to consider.  
    See \bold{Details}}
  \item{max.lh}{logical; if \code{TRUE}, function only outputs for the 
    \code{start.values}/\code{method} combination that results in the highest 
    likelihood}
  \item{plots}{logical; if \code{FALSE} suppresses printing of the histogram, 
    log-histogram and qqplot}
  \item{leave.on}{for use with plotting devices.  When \code{TRUE} does not 
    close off the plotting device (eg. \code{postscript}) after writing the 
    3 plots}
  \item{controlbfgs}{a list of control parameters for \code{optim} when using 
    the \code{"BFGS"} optimisation}
  \item{controlnm}{a list of control parameters for \code{optim}
    when using the \code{"Nelder-Mead"} optimisation}
  \item{maxitnlm}{a positive integer specifying the maximum number of
    iterations when using the \code{"nlm"} optimisation}
  \item{\dots}{passes arguments to \code{par}, \code{hist}, \code{log.hist} 
    and \code{qqplot}}
}
\details{
  Entries in the start.values vector are from the following:
  \itemize{
    \item{\code{"bn"}}{based on Barndorff-Nielsen (1977)}
    \item{\code{"fn"}}{a fitted normal distribution}
    \item{\code{"sl"}}{based on a fitted skew-Laplace distribution}
    \item{\code{"us"}}{specified by the user}
  }
The three optimisation methods currently available are:
\itemize{
\item{\code{"BFGS"}}{uses the quasi-Newton method \code{"BFGS"} as documented 
    in \code{optim}}
\item{\code{"Nelder-Mead"}}{uses an implementation of the Nelder and Mead 
    method as documented in \code{optim}}
\item{\code{"nlm"}}{uses the \code{nlm} function in R}
}

}
\value{
  A list with components
    \item{pars}{a dataframe displaying the results of maximisation.  
      Consists of columns for \code{pi}, \code{zeta}, \code{delta}, \code{mu}, 
      \code{LogLikelihood}, \code{Convergence} and \code{Iterations}.  
      See the relevant documentation (either \code{optim} or \code{nlm}) 
      for details on convergence}
  \item{breaks}{the breaks used}
  \item{starting.values}{a dataframe displaying the various starting values 
    considered}
}

\references{
  Barndorff-Nielsen, O. (1977)
  Exponentially decreasing distributions for the logarithm of particle size,
  \emph{Proc. Roy. Soc. Lond.},
  A\bold{353}, 401--419.
  
  Fieller, N. J., Flenley, E. C. and Olbricht, W. (1992)
  Statistics of particle size data.
  \emph{Appl. Statist.},
  \bold{41}, 127--146.

}

\author{David Scott \email{d.scott@auckland.ac.nz}, 
  Ai-Wei Lee, Jennifer Tso, Richard Trendall}


\seealso{
  \code{\link{optim}}, \code{\link{nlm}}, \code{\link{par}},
  \code{\link{hist}}, \code{\link{log.hist}}, \code{\link{qqplot}}
  and \code{\link{dskewlap}}
}

\examples{
theta <- c(2,2,2,2)
data.vector <- rhyperb(500,theta)
## See how well fit.hyperb works
fit.hyperb(data.vector)


## Use nlm instead of default
fit.hyperb(data.vector,method="nlm")


}

\keyword{distribution}

\eof
\name{hyperb.change.pars}
\alias{hyperb.change.pars}

\title{Change Parameterisations of the Hyperbolic Distribution}

\description{
	This function interchanges between the following 3 parameterisations
	of the Hyperbolic Distribution:
  1. pi, zeta, delta, mu
  2. alpha, beta, delta, mu
  3. phi, gamma, delta, mu}

\usage{
hyperb.change.pars(from, to, theta, no.names=FALSE)
}

\arguments{
  \item{from}{the set of parameters to change from}
  \item{to}{the set of parameters to change to}
  \item{theta}{"from" parameter vector consisting of 4 numerical elements}
  \item{no.names}{logical; when \code{TRUE}, suppresses the parameter
		\code{names} in the output}
}

\details{
In the 3 parameterisations, the following must be positive:
  1. zeta, delta
  2. alpha, delta
  3. phi, gamma, delta
	Furthermore, note that in the second parameterisation alpha must must
	be greater than the absolute value of beta.
}

\value{
	A numerical vector of length 4 representing \code{theta} in the
	\code{to} parameterisation.
}

\references{
  Barndorff-Nielsen, O. and Blaesild, P (1983).
  Hyperbolic distributions. 
  In \emph{Encyclopedia of Statistical Sciences}, 
  eds., Johnson, N. L., Kotz, S. and Read, C. B., Vol. 3,
  pp. 700--707. New York: Wiley.
}

\author{David Scott \email{d.scott@auckland.ac.nz}, 
Jennifer Tso, Richard Trendall}

\seealso{\code{\link{dhyperb}}}

\examples{
theta1 <- c(-2,1,3,0) # Parameter vector in parameterisation 1
theta2 <- hyperb.change.pars(1,2,theta1) # Convert to parameterisation 2
theta2 # Parameter vector in parameterisation 2
hyperb.change.pars(2,1,as.numeric(theta2)) # Convert back to parameterisation 1
}

\keyword{distribution}

\eof
\name{hyperb.mean}
\alias{hyperb.mean}
\alias{hyperb.var}
\alias{hyperb.mode}
\alias{R.lambda}
\alias{S.lambda}
\title{Mean, Variance and Mode of the Hyperbolic Distribution}
\description{
  Functions to calculate the mean, variance, and mode of a specific
  hyperbolic distribution. \code{R.lambda} and \code{S.lambda} are
  functions derived from Bessel functions which are used in the
  calculation of the mean and variance.
}
\usage{
hyperb.mean(theta)
hyperb.var(theta)
hyperb.mode(theta)
R.lambda(zeta, lambda = 1)
S.lambda(zeta, lambda = 1)

}
\arguments{
  \item{theta}{Parameter vector of the hyperbolic distribution}
  \item{zeta}{Value of the parameter zeta of the hyperbolic distribution}
  \item{lambda}{Parameter related to order of Bessel functions}
}

\value{
  \code{hyperb.mean} gives the mean of the hyperbolic distribution,
  \code{hyperb.var} the variance, and \code{hyperb.mode} the mode. 
  The formulae used are as given in Barndorff-Nielsen and Blaesild 
  (1983), p. 702. The functions \code{R.lambda} and \code{S.lambda}
  are used in the calculation of the mean and variance. They are 
  functions of the Bessel functions of the third kind,
  implemented in R as \code{\link{besselK}}.
  
  The parameterisation of the hyperbolic distribution used for this
  and other components of the \code{hyperbolic} package is the
  pi/zeta one. See \code{hyperb.change.pars} to transfer between
  parameterisations.
}
\references{
  Barndorff-Nielsen, O. and Blaesild, P (1983).
  Hyperbolic distributions. 
  In \emph{Encyclopedia of Statistical Sciences}, 
  eds., Johnson, N. L., Kotz, S. and Read, C. B., Vol. 3,
  pp. 700--707. New York: Wiley.
}

\author{David Scott \email{d.scott@auckland.ac.nz}, Richard Trendall}

\seealso{
  \code{\link{dhyperb}}, \code{\link{hyperb.change.pars}}, 
  \code{\link{besselK}}
}

\examples{
theta <- c(2,2,2,2)
hyperb.mean(theta)
hyperb.var(theta)
hyperb.mode(theta)
}
\keyword{distribution}

\eof
\name{log.hist}
\alias{log.hist}
\title{Plot Log-Histogram}
\description{
  Plots a log-histogram, as in for example Feiller, Flenley and
	Olbricht (1992).
	

  The intended use of the log-histogram is to examine the fit of a
  particular density to a set of data, as an alternative to a histogram
  with a density curve. For this reason, only the log-density histogram
  is implemented, and it is not possible to obtain a log-frequency histogram.
}
\usage{
  log.hist(x, breaks = "Sturges", 
  include.lowest = TRUE, right = TRUE, 
  main = paste("Log-Histogram of", xname), 
  xlim = range(breaks), ylim = NULL, xlab = xname, 
  ylab = "Log Density", nclass = NULL, ...)
}
\arguments{
  \item{x}{a vector of values for which the log-histogram is desired}
  \item{breaks}{one of:
    \itemize{
      \item a vector giving the breakpoints between log-histogram cells,
      \item a single number giving the number of cells for the log-histogram,
      \item a character string naming an algorithm to compute the
      number of cells (see Details),
      \item a function to compute the number of cells.
    }
    In the last three cases the number is a suggestion only.
  }
  \item{include.lowest}{logical; if \code{TRUE},
    an `x[i]' equal to the `breaks' value will be included in the first
    (or last, for \code{right = FALSE}) bar.}
  \item{right}{logical; if \code{TRUE}, the log-histograms cells are
    right-closed (left open) intervals.}
  \item{main, xlab, ylab}{these arguments to \code{title} have useful
    defaults here.}
  \item{xlim}{Sensible default for the range of x values}
  \item{ylim}{Calculated by log-hist, see \bold{Details}}
  \item{nclass}{numeric (integer).  For compatibility with \code{hist} only,
    \code{nclass} is equivalent to \code{breaks} for a scalar or
    character argument.}
  \item{\dots}{further graphical parameters for call to \code{plot}.}
}
\details{
  Based on \code{\link{hist.default}}. The code to create cells or
  classes and calculate counts and the density has been taken directly
  from \code{hist.default}. The option of graphing frequencies (or counts)
  present in \code{hist} is not allowed here, so that part of the
  \code{hist.default} code has been commented out.
  
  To calculate \code{ylim} the following procedure is used. The upper
  end of the range is given by the maximum value of the log-density,
  plus 25\% of the absolute value of the maximum. The lower end of the
  range is given by the smallest (finite) value of the log-density, less
  25\% of the difference between the largest and smallest (finite) values 
  of the log-density.
  
  A log-histogram in the form used by Feiller, Flenley and Olbricht (1992)
  is plotted. See also Barndorff-Nielsen (1977) for use of log-histograms.
}
\value{
  Returns a list with components:
  \item{breaks}{the \eqn{n+1} cell boundaries (= \code{breaks} if that
    was a vector).}
  \item{counts}{\eqn{n} integers; for each cell, the number of
    \code{x[]} inside.}
  \item{log.density}{log of \eqn{\hat f(x_i)}{f^(x[i])}, which are estimated
    density values. 
    
    If \code{all(diff(breaks) == 1)}, estimated density values are the
    relative frequencies \code{counts/n} and in general satisfy
    \eqn{\sum_i \hat f(x_i) (b_{i+1}-b_i) = 1}{sum[i; f^(x[i])
      (b[i+1]-b[i])] = 1}, where \eqn{b_i}{b[i]} = \code{breaks[i]}.}
  \item{mids}{the \eqn{n} cell midpoints.}
  \item{xname}{a character string with the actual \code{x} argument name.}
  \item{heights}{the location of the tops of the vertical segments used
    in drawing the log-histogram.}
  \item{ylim}{the value of \code{ylim} calculated by \code{log.hist}.}
}
\references{ 
  Barndorff-Nielsen, O. (1977)
  Exponentially decreasing distributions for the logarithm of particle size,
  \emph{Proc. Roy. Soc. Lond.},
  A\bold{353}, 401--419.
  
  Barndorff-Nielsen, O. and Blaesild, P (1983).
  Hyperbolic distributions. 
  In \emph{Encyclopedia of Statistical Sciences}, 
  eds., Johnson, N. L., Kotz, S. and Read, C. B., Vol. 3,
  pp. 700--707. New York: Wiley.
  
  Fieller, N. J., Flenley, E. C. and Olbricht, W. (1992)
  Statistics of particle size data.
  \emph{Appl. Statist.},
  \bold{41}, 127--146.
}
\author{David Scott \email{d.scott@auckland.ac.nz}, 
Ai-Wei Lee, Jennifer Tso, Richard Trendall}

\seealso{\code{\link{hist}}}

\examples{
data(SandP500)
## Consider proportional changes in the index
change<-SandP500[-length(SandP500)]/SandP500[-1]
hist(change)
log.hist(change)
## Fit the hyperbolic distribution to the changes
fit.hyperb(change)
}
\keyword{hplot}
\keyword{distribution}

\eof
\name{mamquam}
\alias{mamquam}
\title{Size of gravel from Mamquam River}
\usage{data(mamquam)}
\description{
  Size of gravels collected from a sandbar in the Mamquam River,
  British Columbia, Canada. Summary data, giving the frequency of
  observations in 16 different size classes.
}
\format{
  The \code{mamquam} data frame has 16 rows and 2 columns.
  \tabular{rll}{
    [, 1] \tab midpoints  \tab midpoints of intervals (psi units) \cr
    [, 2] \tab counts      \tab number of observations in interval \cr
  }
}
\details{
  Gravel sizes are determined by passing clasts through templates of
  particular sizes. This gives a range in which the size of each clast
  lies. Sizes (in mm) are then converted into psi units by taking the
  base 2 logarithm of the size. The midpoints specified are the midpoints
  of the psi unit ranges, and counts gives the number of observations
  in each size range. The classes are of length 0.5 psi units. 
  There are 3574 observations.
}
\source{
  Rice, Stephen and Church, Michael (1996)
  Sampling surficial gravels: the precision of size distribution
  percentile estimates.
  \emph{J. of Sedimentary Research},
  \bold{66}, 654--665.
}

\examples{
data(mamquam)
str(mamquam)
attach(mamquam)
## construct data from frequency summary, taking all observations
## at midpoints of intervals
psi <- rep(midpoints,counts) 
summary(psi)
## fit the hyperbolic distribution
fit.hyperb(psi)

## actually fit.hyperb can deal with frequency data
fit.hyperb(midpoints, freq=counts)

}
\keyword{datasets}

\eof
\name{resistors}
\alias{resistors}
\title{Resistance of One-half-ohm Resistors }
\description{
    This data set gives the resistance in ohms of 500 nominally one-half-ohm
    resistors, presented in Hahn and Shapiro (1967). Summary data giving the
    frequency of observations in 28 intervals.
}
\usage{data(resistors)}
\format{
  The \code{resistors} data frame has 28 rows and 2 columns.
  \tabular{rll}{
    [, 1] \tab midpoints  \tab midpoints of intervals (ohm) \cr
    [, 2] \tab counts     \tab number of observations in interval \cr
  }    
}
\source{
    Hahn, Gerald J. and Shapiro, Samuel S. (1967)
    \emph{Statistical Models in Engineering}.
    New York: Wiley,
    page 207.
}
\references{
    Chen, Hanfeng, and Kamburowska, Grazyna (2001) 
    Fitting data to the Johnson system.
    \emph{J. Statist. Comput. Simul.},
    \bold{70}, 21--32.
}
\examples{
data(resistors)
str(resistors)
attach(resistors)
## construct data from frequency summary, taking all observations
## at midpoints of intervals
resistances <- rep(midpoints,counts)
hist(resistances)
log.hist(resistances)
## fit the hyperbolic distribution
fit.hyperb(resistances) 

## actually fit.hyperb can deal with frequency data
fit.hyperb(midpoints, freq=counts)

}
\keyword{datasets}

\eof
